<template>
  <FormSection
    description="app.profile.password.description"
    title="app.profile.password.title"
  >
    <FormGroup @submit="submit">
      <AlertError v-if="form.errors && form.errors?.unknown">
        {{ form.errors.unknown }}
      </AlertError>
      <FormInput
        id="profile_current_password"
        :errors="form.errors.current_password"
      >
        <FormLabel>{{ $t("app.profile.form.current_password") }}</FormLabel>
        <FormText
          v-model="form.values.current_password"
          autocomplete="password"
          name="current_password"
          required
          type="password"
        />
      </FormInput>
      <FormInput
        id="profile_password"
        :errors="form.errors.password"
      >
        <FormLabel>{{ $t("app.profile.form.password") }}</FormLabel>
        <FormText
          v-model="form.values.password"
          autocomplete="new-password"
          name="password"
          required
          type="password"
        />
      </FormInput>
      <FormInput
        id="profile_password_confirmation"
        :errors="form.errors.password_confirmation"
      >
        <FormLabel>{{ $t("app.profile.form.password_confirmation") }}</FormLabel>
        <FormText
          v-model="form.values.password_confirmation"
          autocomplete="new-password"
          name="password_confirmation"
          required
          type="password"
        />
      </FormInput>
      <div>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-black"
        >
          {{ $t("app.profile.password.submit") }}
        </FormSubmit>
      </div>
    </FormGroup>
  </FormSection>
</template>

<script lang="ts" setup>
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

const { t } = useI18n();
const { successNotification } = useNotification();

const form = useForm({
  current_password: "",
  password: "",
  password_confirmation: "",
});

const submit = () => {
  form.post("/profile/password", {
    onSuccess: () => {
      form.reset();
      successNotification(t("app.profile.password.success"));
    },
  });
};
</script>
